@@ -69,6 +69,10 @@ queue_pass <- function(arrivals, service, servers){
   UseMethod("queue_pass", servers)
 }
 
+queue_pass.integer <- function(arrivals, service, servers){
+  servers <- as.numeric(servers)
+  queue_pass.numeric(arrivals, service, servers)
+}
 
 queue_pass.numeric <- function(arrivals, service, servers){
   stopifnot((servers%%1 == 0) & (servers > 0))
@@ -168,6 +172,11 @@ queue_pass.server.list <- function(arrivals, service, servers){
 queue_step <- function(arrivals, service, servers = 1, labels = NULL){
 
   arrivals <- depart(arrivals)
+  service <- as.numeric(service)
+
+  if("integer" %in% class(servers)){
+    servers <- as.numeric(servers)
+  }
 
   departures <- queue(arrivals = arrivals, service = service, servers = servers, serveroutput = TRUE)
 
@@ -320,9 +329,9 @@ wait_step <- function(arrivals, service){
 #' queue_obj$departures_df$departures
 depart <- function(x){
   if("numeric" %in% class(x) | "integer" %in% class(x)){
-    departures <- x
+    departures <- as.numeric(x)
   } else {
-    departures <- x$departures_df$departures
+    departures <- as.numeric(x$departures_df$departures)
   }
   return(departures)
 }
